@@ -73,29 +73,6 @@ tree_view_show_popup_menu (GdkEventButton *event,
                            GtkTreeViewColumn *column)
 {
         GtkMenu *menu;
-        GtkWidget *view;
-        const gchar *column_name;
-        const gchar *column_title;
-        GvaGameStoreColumn column_id;
-        gchar *label, *tooltip;
-
-        view = gtk_tree_view_column_get_tree_view (column);
-        g_object_set_data (G_OBJECT (view), "popup-menu-column", column);
-        column_name = g_object_get_data (G_OBJECT (column), "name");
-        gva_columns_lookup_id (column_name, &column_id);
-        column_title = gva_columns_lookup_title (column_id);
-
-        /* Update the "Remove Column" item in the popup menu. */
-        label = g_strdup_printf (
-                _("Remove %s Column"), column_title);
-        tooltip = g_strdup_printf (
-                _("Remove the \"%s\" column from the game list"),
-                column_title);
-        g_object_set (
-                GVA_ACTION_REMOVE_COLUMN, "label",
-                label, "tooltip", tooltip, NULL);
-        g_free (tooltip);
-        g_free (label);
 
         menu = GTK_MENU (gva_ui_get_managed_widget ("/game-popup"));
 
