@@ -28,6 +28,7 @@
 #include "gva-game-store.h"
 #include "gva-main.h"
 #include "gva-mame.h"
+#include "gva-mute-button.h"
 #include "gva-play-back.h"
 #include "gva-preferences.h"
 #include "gva-process.h"
@@ -831,7 +832,9 @@ ui_init (void)
         filename = gva_find_data_file (PACKAGE ".glade");
         if (filename != NULL)
         {
+                REGISTER_WIDGET (GTK_TYPE_LINK_BUTTON);
                 REGISTER_WIDGET (GVA_TYPE_COLUMN_MANAGER);
+                REGISTER_WIDGET (GVA_TYPE_MUTE_BUTTON);
 
                 glade_provide ("gva");
                 xml = glade_xml_new (filename, NULL, NULL);
@@ -1002,7 +1005,7 @@ gva_ui_add_column_actions (GtkTreeView *view)
 
                 gtk_ui_manager_add_ui (
                         manager, merge_id,
-                        "/game-popup/add-column",
+                        "/column-popup/add-column",
                         action_name, action_name,
                         GTK_UI_MANAGER_AUTO, FALSE);
 
